#ifndef YY_SamplinParser_h_included
#define YY_SamplinParser_h_included

#line 1 "/usr/local/lib/bison.h"
/* before anything */
#ifdef c_plusplus
#ifndef __cplusplus
#define __cplusplus
#endif
#endif
#ifdef __cplusplus
#ifndef YY_USE_CLASS
#define YY_USE_CLASS
#endif
#else
#endif
#include <stdio.h>

/* #line 14 "/usr/local/lib/bison.h" */
#line 21 "script.bison.h"
#define YY_SamplinParser_ERROR_BODY =0;
#define YY_SamplinParser_DEBUG  1
#define YY_SamplinParser_LEX_BODY  = 0
#define YY_SamplinParser_CONSTRUCTOR_CODE  \
cmp_flag=0; \
//yydebug=1;
#define YY_SamplinParser_MEMBERS  \
public: \
virtual void yyunput(int)=0; \
virtual void create_goto(char *)=0; \
virtual void create_negate(void)=0; \
virtual void create_pushdblsymptr(char *)=0; \
virtual void create_pushdblsym(char *, int )=0; \
virtual void create_pushdblsym2(char *)=0; \
virtual void create_popdblsym(char *, int )=0; \
virtual void create_popdblsym2(char *, int)=0; \
virtual void create_pushdbl(double)=0; \
virtual void create_pushdblp(double *)=0; \
virtual void create_popdbl(double *)=0; \
virtual void create_unaryassign(int,int)=0; \
virtual void create_binop(int)=0; \
virtual void create_relop(int)=0; \
virtual void create_pushstrsym(char *)=0; \
virtual void create_popstrsym(char *)=0; \
virtual void create_concat(void)=0; \
virtual void create_pushstr(char *)=0; \
virtual void create_strrelop(int)=0; \
virtual void create_print(char)=0; \
virtual void create_myread(char)=0; \
virtual void create_myreaddlg(char)=0; \
virtual void create_prompt(char *)=0; \
virtual void create_myopen(double,char *)=0; \
virtual void create_myclose(double)=0; \
virtual void create_myswitch(double)=0; \
virtual void create_gosub(char *)=0; \
virtual void create_label(char *)=0; \
virtual void create_return(void)=0; \
virtual void create_skipper(void)=0; \
virtual void create_nop(void)=0; \
virtual void create_myend(void)=0; \
virtual void create_decide(void)=0; \
virtual void create_function(int, char *)=0; \
virtual void create_doarray(char *,int)=0; \
virtual void create_dim(char *,char)=0; \
virtual void create_restore(char *)=0; \
virtual void create_dbldata(double)=0; \
virtual void create_strdata(char *)=0; \
virtual void create_readdata(char)=0; \
virtual void create_mywait()=0; \
virtual void create_bell()=0; \
virtual void create_devopen(char *)=0; \
virtual void create_devclose(char *)=0; \
virtual void create_devrd(char *,int)=0; \
virtual void create_devrdb(char *, char *)=0; \
virtual void create_devwr(char *,int)=0; \
virtual void create_devwrb(char *, char *)=0; \
virtual void create_devctl(char *)=0; \
virtual void create_devflush(char *)=0; \
virtual void create_devseek(char *,int)=0; \
virtual void create_message(char)=0; \
virtual void create_plotfnc(int,char*,char*)=0;\
virtual void create_graphfnc(int,int,char*,char*)=0;\
virtual void create_addgraph()=0; \
virtual void create_delgraph()=0; \
virtual void create_loadgraph(int)=0; \
virtual void create_savegraph(int)=0; \
virtual void create_exportgraph(int)=0; \
virtual void create_printgraph()=0; \
virtual void create_adddlg(char *)=0; \
virtual void create_deldlg(char *)=0; \
virtual void create_hidedlg(char *)=0; \
virtual void create_showdlg(char *)=0; \
virtual void create_progressdlg(int,int)=0; \
virtual void create_addwidget(char *, int, char *, char * )=0; \
virtual void create_mysleep()=0; \
virtual void create_multi(int )=0; \
virtual void create_timer(int )=0; \
virtual void create_cursor(int )=0;\
virtual void inccounter(void)=0; \
virtual void pushdummy(void)=0; \
virtual void pushlabel(void)=0; \
virtual void poplabel(void)=0; \
virtual void swap(void)=0; \
virtual struct stackentry *pop(void)=0; \
virtual void pushgoto(void)=0; \
virtual void popgoto(void)=0;\
virtual void pushcopy(void)=0; \
virtual void pushcounter(void)=0; \
virtual void pushname(char *)=0; \
virtual void error(int, const char*,...)=0; \
virtual void pushint(int)=0; \
char const *tname(int token);\
\
enum functions { \
   MYRAN2,MYINKEY,MYREADY,MYSPOLL,MYACTIVE,MYDATE,MYTIME,ZEROARGS,MYABS,MYSGN,MYSIN,MYASIN,MYCOS,MYACOS,MYTAN,MYATAN, \
   MYEXP,MYLOG,MYLEN,MYSTR,MYCHR,MYSQRT,MYFRAC,MYRAN,MYINT,MYVAL,MYASC, \
   ONEARGS,MYATAN2,MYLEFT,MYRIGHT,TWOARGS,MYMID \
}; \
enum arraymode { \
   CALLARRAY,ASSIGNARRAY,CALLSTRINGARRAY,ASSIGNSTRINGARRAY, CALLPTRARRAY, \
   CALLPTRSTRARRAY \
}; \
enum stackmode { \
   SINGLE, ARRAY, PUSHBACK=0x0100, PUSHBEFORE=0x0200, PUSHAFTER=0x0400 \
}; \
enum plotfnc { \
PLOTADD,PLOTDEL,PLOTSETDATA,PLOTSETDATAX,PLOTSETDATAY, \
PLOTSETDATAL,PLOTSETDATAXL,PLOTSETDATAYL,PLOTGETDATA,PLOTAXES,PLOTSTYLE,\
PLOTPEN, PLOTSYMBOL\
}; \
enum graphfnc { \
GRAPHCOLORS, GRAPHAXISTITLE, GRAPHTITLE, GRAPHCOMMENT, GRAPHLEGEND, GRAPHAXISSTYLE, GRAPHAXISFLAGS, \
GRAPHAXISSCALE \
}; \
int errorlevel; \
int myflag;\
struct command *lastcommand; \
int yylineno; \
int cmp_flag;\


#line 152 "script.bison.y"
typedef union {
  double number;        /* double number */
  int token;            /* token of command */
  char *string;         /* quoted string */
  char *symbol;         /* general symbol */
  char *strsym;         /* string symbol */
  char *arraysym;       /* array symbol */
  char *arraystrsym;
  char sep;
//  int unaryop;
//  int binaryop;
} yy_SamplinParser_stype;
#define YY_SamplinParser_STYPE yy_SamplinParser_stype

#line 14 "/usr/local/lib/bison.h"
 /* %{ and %header{ and %union, during decl */
#ifndef YY_SamplinParser_COMPATIBILITY
#ifndef YY_USE_CLASS
#define  YY_SamplinParser_COMPATIBILITY 1
#else
#define  YY_SamplinParser_COMPATIBILITY 0
#endif
#endif

#if YY_SamplinParser_COMPATIBILITY != 0
/* backward compatibility */
#ifdef YYLTYPE
#ifndef YY_SamplinParser_LTYPE
#define YY_SamplinParser_LTYPE YYLTYPE
/* WARNING obsolete !!! user defined YYLTYPE not reported into generated header */
/* use %define LTYPE */
#endif
#endif
#ifdef YYSTYPE
#ifndef YY_SamplinParser_STYPE 
#define YY_SamplinParser_STYPE YYSTYPE
/* WARNING obsolete !!! user defined YYSTYPE not reported into generated header */
/* use %define STYPE */
#endif
#endif
#ifdef YYDEBUG
#ifndef YY_SamplinParser_DEBUG
#define  YY_SamplinParser_DEBUG YYDEBUG
/* WARNING obsolete !!! user defined YYDEBUG not reported into generated header */
/* use %define DEBUG */
#endif
#endif
#ifdef YY_SamplinParser_STYPE
#ifndef yystype
#define yystype YY_SamplinParser_STYPE
#endif
#endif
/* use goto to be compatible */
#ifndef YY_SamplinParser_USE_GOTO
#define YY_SamplinParser_USE_GOTO 1
#endif
#endif

/* use no goto to be clean in C++ */
#ifndef YY_SamplinParser_USE_GOTO
#define YY_SamplinParser_USE_GOTO 0
#endif

#ifndef YY_SamplinParser_PURE

/* #line 63 "/usr/local/lib/bison.h" */
#line 210 "script.bison.h"

#line 63 "/usr/local/lib/bison.h"
/* YY_SamplinParser_PURE */
#endif

/* #line 65 "/usr/local/lib/bison.h" */
#line 217 "script.bison.h"

#line 65 "/usr/local/lib/bison.h"
/* prefix */
#ifndef YY_SamplinParser_DEBUG

/* #line 67 "/usr/local/lib/bison.h" */
#line 224 "script.bison.h"

#line 67 "/usr/local/lib/bison.h"
/* YY_SamplinParser_DEBUG */
#endif
#ifndef YY_SamplinParser_LSP_NEEDED

/* #line 70 "/usr/local/lib/bison.h" */
#line 232 "script.bison.h"

#line 70 "/usr/local/lib/bison.h"
 /* YY_SamplinParser_LSP_NEEDED*/
#endif
/* DEFAULT LTYPE*/
#ifdef YY_SamplinParser_LSP_NEEDED
#ifndef YY_SamplinParser_LTYPE
typedef
  struct yyltype
    {
      int timestamp;
      int first_line;
      int first_column;
      int last_line;
      int last_column;
      char *text;
   }
  yyltype;

#define YY_SamplinParser_LTYPE yyltype
#endif
#endif
/* DEFAULT STYPE*/
#ifndef YY_SamplinParser_STYPE
#define YY_SamplinParser_STYPE int
#endif
/* DEFAULT MISCELANEOUS */
#ifndef YY_SamplinParser_PARSE
#define YY_SamplinParser_PARSE yyparse
#endif
#ifndef YY_SamplinParser_LEX
#define YY_SamplinParser_LEX yylex
#endif
#ifndef YY_SamplinParser_LVAL
#define YY_SamplinParser_LVAL yylval
#endif
#ifndef YY_SamplinParser_LLOC
#define YY_SamplinParser_LLOC yylloc
#endif
#ifndef YY_SamplinParser_CHAR
#define YY_SamplinParser_CHAR yychar
#endif
#ifndef YY_SamplinParser_NERRS
#define YY_SamplinParser_NERRS yynerrs
#endif
#ifndef YY_SamplinParser_DEBUG_FLAG
#define YY_SamplinParser_DEBUG_FLAG yydebug
#endif
#ifndef YY_SamplinParser_ERROR
#define YY_SamplinParser_ERROR yyerror
#endif

#ifndef YY_SamplinParser_PARSE_PARAM
#ifndef __STDC__
#ifndef __cplusplus
#ifndef YY_USE_CLASS
#define YY_SamplinParser_PARSE_PARAM
#ifndef YY_SamplinParser_PARSE_PARAM_DEF
#define YY_SamplinParser_PARSE_PARAM_DEF
#endif
#endif
#endif
#endif
#ifndef YY_SamplinParser_PARSE_PARAM
#define YY_SamplinParser_PARSE_PARAM void
#endif
#endif

/* TOKEN C */
#ifndef YY_USE_CLASS

#ifndef YY_SamplinParser_PURE
extern YY_SamplinParser_STYPE YY_SamplinParser_LVAL;
#endif


/* #line 143 "/usr/local/lib/bison.h" */
#line 310 "script.bison.h"
#define	DECNUMBER	258
#define	HEXNUMBER	259
#define	SYMBOL	260
#define	STRSYM	261
#define	STRING	262
#define	ARRAYSYM	263
#define	ARRAYSTRSYM	264
#define	SEP	265
#define	SPC	266
#define	FOR	267
#define	TO	268
#define	STEP	269
#define	NEXT	270
#define	GOTO	271
#define	GOSUB	272
#define	LABEL	273
#define	ON	274
#define	IF	275
#define	THEN	276
#define	ELSE	277
#define	ENDIF	278
#define	WHILE	279
#define	DO	280
#define	BREAK	281
#define	PRINT	282
#define	INPUT	283
#define	RETURN	284
#define	DIM	285
#define	END	286
#define	PLUSPLUS	287
#define	MINUSMINUS	288
#define	LEFTOP	289
#define	RIGHTOP	290
#define	MULEQ	291
#define	PLUSEQ	292
#define	MINUSEQ	293
#define	DIVEQ	294
#define	ANDEQ	295
#define	OREQ	296
#define	XOREQ	297
#define	ISEQ	298
#define	POWEQ	299
#define	LEFTEQ	300
#define	RIGHTEQ	301
#define	PLS	302
#define	MNS	303
#define	DVD	304
#define	MLP	305
#define	PWR	306
#define	AND	307
#define	OR	308
#define	XOR	309
#define	ANDAND	310
#define	OROR	311
#define	NOT	312
#define	NE	313
#define	LE	314
#define	GE	315
#define	LT	316
#define	GT	317
#define	EQ	318
#define	READ	319
#define	DATA	320
#define	RESTORE	321
#define	OPEN	322
#define	CLOSE	323
#define	WINDOW	324
#define	DOT	325
#define	LINE	326
#define	CIRCLE	327
#define	TEXT	328
#define	CLEAR	329
#define	PRINTER	330
#define	WAIT	331
#define	BELL	332
#define	EOFILE	333
#define	SIN	334
#define	ASIN	335
#define	COS	336
#define	ACOS	337
#define	TAN	338
#define	ATAN	339
#define	EXP	340
#define	LOG	341
#define	SQRT	342
#define	ABS	343
#define	SGN	344
#define	INT	345
#define	FRAC	346
#define	RAN	347
#define	LEN	348
#define	VAL	349
#define	LEFT_	350
#define	RIGHT_	351
#define	MID	352
#define	STR	353
#define	CHR	354
#define	INKEY	355
#define	ASC	356
#define	DEVRD	357
#define	DEVWR	358
#define	DEVOPEN	359
#define	DEVCLOSE	360
#define	DEVCTL	361
#define	DEVSPOLL	362
#define	DEVSEEK	363
#define	DEVFLUSH	364
#define	START	365
#define	CURRENT	366
#define	MESSAGE	367
#define	M_INFO	368
#define	M_WARNING	369
#define	M_ERROR	370
#define	ADDXPLOT	371
#define	ADDYPLOT	372
#define	ADDXYPLOT	373
#define	UPDATEXPLOT	374
#define	UPDATEYPLOT	375
#define	UPDATEXYPLOT	376
#define	DELPLOT	377
#define	TITLEGRAPH	378
#define	ADDGRAPH	379
#define	DELGRAPH	380
#define	LOADGRAPH	381
#define	SAVEGRAPH	382
#define	EXPORTGRAPH	383
#define	PRINTGRAPH	384
#define	ADDPLOT	385
#define	SETPLOTDATA	386
#define	GETPLOTDATA	387
#define	SETPLOTAXES	388
#define	SETPLOTSTYLE	389
#define	SETPLOTPEN	390
#define	SETPLOTSYMBOL	391
#define	SETGRAPHTITLE	392
#define	SETGRAPHCOMMENT	393
#define	SETAXISTITLE	394
#define	SETAXISFLAGS	395
#define	SETAXISSCALE	396
#define	SETAXISSTYLE	397
#define	SETGRAPHLEGEND	398
#define	SETGRAPHCOLORS	399
#define	AUTO	400
#define	REF	401
#define	INV	402
#define	SYM	403
#define	FLT	404
#define	LEFT	405
#define	RIGHT	406
#define	TOP	407
#define	BOTTOM	408
#define	ADDDLG	409
#define	DELDLG	410
#define	HIDEDLG	411
#define	SHOWDLG	412
#define	PROGRESSDLG	413
#define	ADDWIDGET	414
#define	BUTTON	415
#define	SWITCH	416
#define	LCD	417
#define	LED	418
#define	DLGACTIVE	419
#define	INPUTDLG	420
#define	FRAME	421
#define	WHEEL	422
#define	SELECT	423
#define	GRAPH	424
#define	KNOB	425
#define	LEVEL	426
#define	SLIDER	427
#define	SLEEP	428
#define	MULTI	429
#define	OFF	430
#define	IDLE	431
#define	DEVREADY	432
#define	CURSOR	433
#define	DEFAULT	434
#define	TIMER	435
#define	DATE	436
#define	TIME	437
#define	LOWER_THAN_ELSE	438
#define	UMINUS	439


#line 143 "/usr/local/lib/bison.h"
 /* #defines token */
/* after #define tokens, before const tokens S5*/
#else
#ifndef YY_SamplinParser_CLASS
#define YY_SamplinParser_CLASS SamplinParser
#endif

#ifndef YY_SamplinParser_INHERIT
#define YY_SamplinParser_INHERIT
#endif
#ifndef YY_SamplinParser_MEMBERS
#define YY_SamplinParser_MEMBERS 
#endif
#ifndef YY_SamplinParser_LEX_BODY
#define YY_SamplinParser_LEX_BODY  
#endif
#ifndef YY_SamplinParser_ERROR_BODY
#define YY_SamplinParser_ERROR_BODY  
#endif
#ifndef YY_SamplinParser_CONSTRUCTOR_PARAM
#define YY_SamplinParser_CONSTRUCTOR_PARAM
#endif
/* choose between enum and const */
#ifndef YY_SamplinParser_USE_CONST_TOKEN
#define YY_SamplinParser_USE_CONST_TOKEN 0
/* yes enum is more compatible with flex,  */
/* so by default we use it */ 
#endif
#if YY_SamplinParser_USE_CONST_TOKEN != 0
#ifndef YY_SamplinParser_ENUM_TOKEN
#define YY_SamplinParser_ENUM_TOKEN yy_SamplinParser_enum_token
#endif
#endif

class YY_SamplinParser_CLASS YY_SamplinParser_INHERIT
{
public: 
#if YY_SamplinParser_USE_CONST_TOKEN != 0
/* static const int token ... */

/* #line 182 "/usr/local/lib/bison.h" */
#line 537 "script.bison.h"
static const int DECNUMBER;
static const int HEXNUMBER;
static const int SYMBOL;
static const int STRSYM;
static const int STRING;
static const int ARRAYSYM;
static const int ARRAYSTRSYM;
static const int SEP;
static const int SPC;
static const int FOR;
static const int TO;
static const int STEP;
static const int NEXT;
static const int GOTO;
static const int GOSUB;
static const int LABEL;
static const int ON;
static const int IF;
static const int THEN;
static const int ELSE;
static const int ENDIF;
static const int WHILE;
static const int DO;
static const int BREAK;
static const int PRINT;
static const int INPUT;
static const int RETURN;
static const int DIM;
static const int END;
static const int PLUSPLUS;
static const int MINUSMINUS;
static const int LEFTOP;
static const int RIGHTOP;
static const int MULEQ;
static const int PLUSEQ;
static const int MINUSEQ;
static const int DIVEQ;
static const int ANDEQ;
static const int OREQ;
static const int XOREQ;
static const int ISEQ;
static const int POWEQ;
static const int LEFTEQ;
static const int RIGHTEQ;
static const int PLS;
static const int MNS;
static const int DVD;
static const int MLP;
static const int PWR;
static const int AND;
static const int OR;
static const int XOR;
static const int ANDAND;
static const int OROR;
static const int NOT;
static const int NE;
static const int LE;
static const int GE;
static const int LT;
static const int GT;
static const int EQ;
static const int READ;
static const int DATA;
static const int RESTORE;
static const int OPEN;
static const int CLOSE;
static const int WINDOW;
static const int DOT;
static const int LINE;
static const int CIRCLE;
static const int TEXT;
static const int CLEAR;
static const int PRINTER;
static const int WAIT;
static const int BELL;
static const int EOFILE;
static const int SIN;
static const int ASIN;
static const int COS;
static const int ACOS;
static const int TAN;
static const int ATAN;
static const int EXP;
static const int LOG;
static const int SQRT;
static const int ABS;
static const int SGN;
static const int INT;
static const int FRAC;
static const int RAN;
static const int LEN;
static const int VAL;
static const int LEFT_;
static const int RIGHT_;
static const int MID;
static const int STR;
static const int CHR;
static const int INKEY;
static const int ASC;
static const int DEVRD;
static const int DEVWR;
static const int DEVOPEN;
static const int DEVCLOSE;
static const int DEVCTL;
static const int DEVSPOLL;
static const int DEVSEEK;
static const int DEVFLUSH;
static const int START;
static const int CURRENT;
static const int MESSAGE;
static const int M_INFO;
static const int M_WARNING;
static const int M_ERROR;
static const int ADDXPLOT;
static const int ADDYPLOT;
static const int ADDXYPLOT;
static const int UPDATEXPLOT;
static const int UPDATEYPLOT;
static const int UPDATEXYPLOT;
static const int DELPLOT;
static const int TITLEGRAPH;
static const int ADDGRAPH;
static const int DELGRAPH;
static const int LOADGRAPH;
static const int SAVEGRAPH;
static const int EXPORTGRAPH;
static const int PRINTGRAPH;
static const int ADDPLOT;
static const int SETPLOTDATA;
static const int GETPLOTDATA;
static const int SETPLOTAXES;
static const int SETPLOTSTYLE;
static const int SETPLOTPEN;
static const int SETPLOTSYMBOL;
static const int SETGRAPHTITLE;
static const int SETGRAPHCOMMENT;
static const int SETAXISTITLE;
static const int SETAXISFLAGS;
static const int SETAXISSCALE;
static const int SETAXISSTYLE;
static const int SETGRAPHLEGEND;
static const int SETGRAPHCOLORS;
static const int AUTO;
static const int REF;
static const int INV;
static const int SYM;
static const int FLT;
static const int LEFT;
static const int RIGHT;
static const int TOP;
static const int BOTTOM;
static const int ADDDLG;
static const int DELDLG;
static const int HIDEDLG;
static const int SHOWDLG;
static const int PROGRESSDLG;
static const int ADDWIDGET;
static const int BUTTON;
static const int SWITCH;
static const int LCD;
static const int LED;
static const int DLGACTIVE;
static const int INPUTDLG;
static const int FRAME;
static const int WHEEL;
static const int SELECT;
static const int GRAPH;
static const int KNOB;
static const int LEVEL;
static const int SLIDER;
static const int SLEEP;
static const int MULTI;
static const int OFF;
static const int IDLE;
static const int DEVREADY;
static const int CURSOR;
static const int DEFAULT;
static const int TIMER;
static const int DATE;
static const int TIME;
static const int LOWER_THAN_ELSE;
static const int UMINUS;


#line 182 "/usr/local/lib/bison.h"
 /* decl const */
#else
enum YY_SamplinParser_ENUM_TOKEN { YY_SamplinParser_NULL_TOKEN=0

/* #line 185 "/usr/local/lib/bison.h" */
#line 728 "script.bison.h"
	,DECNUMBER=258
	,HEXNUMBER=259
	,SYMBOL=260
	,STRSYM=261
	,STRING=262
	,ARRAYSYM=263
	,ARRAYSTRSYM=264
	,SEP=265
	,SPC=266
	,FOR=267
	,TO=268
	,STEP=269
	,NEXT=270
	,GOTO=271
	,GOSUB=272
	,LABEL=273
	,ON=274
	,IF=275
	,THEN=276
	,ELSE=277
	,ENDIF=278
	,WHILE=279
	,DO=280
	,BREAK=281
	,PRINT=282
	,INPUT=283
	,RETURN=284
	,DIM=285
	,END=286
	,PLUSPLUS=287
	,MINUSMINUS=288
	,LEFTOP=289
	,RIGHTOP=290
	,MULEQ=291
	,PLUSEQ=292
	,MINUSEQ=293
	,DIVEQ=294
	,ANDEQ=295
	,OREQ=296
	,XOREQ=297
	,ISEQ=298
	,POWEQ=299
	,LEFTEQ=300
	,RIGHTEQ=301
	,PLS=302
	,MNS=303
	,DVD=304
	,MLP=305
	,PWR=306
	,AND=307
	,OR=308
	,XOR=309
	,ANDAND=310
	,OROR=311
	,NOT=312
	,NE=313
	,LE=314
	,GE=315
	,LT=316
	,GT=317
	,EQ=318
	,READ=319
	,DATA=320
	,RESTORE=321
	,OPEN=322
	,CLOSE=323
	,WINDOW=324
	,DOT=325
	,LINE=326
	,CIRCLE=327
	,TEXT=328
	,CLEAR=329
	,PRINTER=330
	,WAIT=331
	,BELL=332
	,EOFILE=333
	,SIN=334
	,ASIN=335
	,COS=336
	,ACOS=337
	,TAN=338
	,ATAN=339
	,EXP=340
	,LOG=341
	,SQRT=342
	,ABS=343
	,SGN=344
	,INT=345
	,FRAC=346
	,RAN=347
	,LEN=348
	,VAL=349
	,LEFT_=350
	,RIGHT_=351
	,MID=352
	,STR=353
	,CHR=354
	,INKEY=355
	,ASC=356
	,DEVRD=357
	,DEVWR=358
	,DEVOPEN=359
	,DEVCLOSE=360
	,DEVCTL=361
	,DEVSPOLL=362
	,DEVSEEK=363
	,DEVFLUSH=364
	,START=365
	,CURRENT=366
	,MESSAGE=367
	,M_INFO=368
	,M_WARNING=369
	,M_ERROR=370
	,ADDXPLOT=371
	,ADDYPLOT=372
	,ADDXYPLOT=373
	,UPDATEXPLOT=374
	,UPDATEYPLOT=375
	,UPDATEXYPLOT=376
	,DELPLOT=377
	,TITLEGRAPH=378
	,ADDGRAPH=379
	,DELGRAPH=380
	,LOADGRAPH=381
	,SAVEGRAPH=382
	,EXPORTGRAPH=383
	,PRINTGRAPH=384
	,ADDPLOT=385
	,SETPLOTDATA=386
	,GETPLOTDATA=387
	,SETPLOTAXES=388
	,SETPLOTSTYLE=389
	,SETPLOTPEN=390
	,SETPLOTSYMBOL=391
	,SETGRAPHTITLE=392
	,SETGRAPHCOMMENT=393
	,SETAXISTITLE=394
	,SETAXISFLAGS=395
	,SETAXISSCALE=396
	,SETAXISSTYLE=397
	,SETGRAPHLEGEND=398
	,SETGRAPHCOLORS=399
	,AUTO=400
	,REF=401
	,INV=402
	,SYM=403
	,FLT=404
	,LEFT=405
	,RIGHT=406
	,TOP=407
	,BOTTOM=408
	,ADDDLG=409
	,DELDLG=410
	,HIDEDLG=411
	,SHOWDLG=412
	,PROGRESSDLG=413
	,ADDWIDGET=414
	,BUTTON=415
	,SWITCH=416
	,LCD=417
	,LED=418
	,DLGACTIVE=419
	,INPUTDLG=420
	,FRAME=421
	,WHEEL=422
	,SELECT=423
	,GRAPH=424
	,KNOB=425
	,LEVEL=426
	,SLIDER=427
	,SLEEP=428
	,MULTI=429
	,OFF=430
	,IDLE=431
	,DEVREADY=432
	,CURSOR=433
	,DEFAULT=434
	,TIMER=435
	,DATE=436
	,TIME=437
	,LOWER_THAN_ELSE=438
	,UMINUS=439


#line 185 "/usr/local/lib/bison.h"
 /* enum token */
     }; /* end of enum declaration */
#endif
public:
 int YY_SamplinParser_PARSE(YY_SamplinParser_PARSE_PARAM);
 virtual void YY_SamplinParser_ERROR(char *msg) YY_SamplinParser_ERROR_BODY;
#ifdef YY_SamplinParser_PURE
#ifdef YY_SamplinParser_LSP_NEEDED
 virtual int  YY_SamplinParser_LEX(YY_SamplinParser_STYPE *YY_SamplinParser_LVAL,YY_SamplinParser_LTYPE *YY_SamplinParser_LLOC) YY_SamplinParser_LEX_BODY;
#else
 virtual int  YY_SamplinParser_LEX(YY_SamplinParser_STYPE *YY_SamplinParser_LVAL) YY_SamplinParser_LEX_BODY;
#endif
#else
 virtual int YY_SamplinParser_LEX() YY_SamplinParser_LEX_BODY;
 YY_SamplinParser_STYPE YY_SamplinParser_LVAL;
#ifdef YY_SamplinParser_LSP_NEEDED
 YY_SamplinParser_LTYPE YY_SamplinParser_LLOC;
#endif
 int YY_SamplinParser_NERRS;
 int YY_SamplinParser_CHAR;
#endif
#if YY_SamplinParser_DEBUG != 0
public:
 int YY_SamplinParser_DEBUG_FLAG;	/*  nonzero means print parse trace	*/
#endif
public:
 YY_SamplinParser_CLASS(YY_SamplinParser_CONSTRUCTOR_PARAM);
public:
 YY_SamplinParser_MEMBERS 
};
/* other declare folow */
#endif


#if YY_SamplinParser_COMPATIBILITY != 0
/* backward compatibility */
#ifndef YYSTYPE
#define YYSTYPE YY_SamplinParser_STYPE
#endif

#ifndef YYLTYPE
#define YYLTYPE YY_SamplinParser_LTYPE
#endif
#ifndef YYDEBUG
#ifdef YY_SamplinParser_DEBUG 
#define YYDEBUG YY_SamplinParser_DEBUG
#endif
#endif

#endif
/* END */

/* #line 236 "/usr/local/lib/bison.h" */
#line 967 "script.bison.h"
#endif
